import React, {Component} from 'react';
import {bind} from 'ola-toolkit';
import {List, Avatar, Button, Spin} from 'ola-ui';

export default class Async extends React.Component {

  state = {
    loading: true,
    loadingMore: false,
    showLoadingMore: true,
    data: [],
  };

  componentDidMount() {
    this.getData().then((res) => {
      this.setState({
        loading: false,
        data: res.result,
      });
    });
  }

  @bind
  getData() {
    return new Promise((resolve) => {
      const count = this.state.data.length;
      const data = Array(5).fill().map((v, i) => ({
        index: i + count
      }));

      setTimeout(() => {
        resolve({
          result: data
        });
      }, 2e3);
    });
  }

  @bind
  onLoadMore() {
    this.setState({
      loadingMore: true,
    });

    this.getData().then((res) => {
      const data = this.state.data.concat(res.result);
      this.setState({
        data,
        loadingMore: false,
      });
    });
  }

  render() {
    const {loading, loadingMore, showLoadingMore, data} = this.state;
    const loadMore = showLoadingMore ? (
      <div style={{textAlign: 'center', marginTop: 12, height: 32, lineHeight: '32px'}}>
        {loadingMore && <Spin/>}
        {!loadingMore && <Button onClick={this.onLoadMore}>loading more</Button>}
      </div>
    ) : null;
    return (
      <List
        loading={loading}
        itemLayout="horizontal"
        loadMore={loadMore}
        dataSource={data}
        renderItem={item => (
          <List.Item actions={[<a>action</a>]}>
            <List.Item.Meta
              avatar={<Avatar src="https://storage.jd.com/ola-ui/img/defaultAvatar.png"/>}
              title={<a href="#">{item.index}</a>}
              description={<div>description for {item.index}</div>}
            />
            <div>content</div>
          </List.Item>
        )}
      />
    );
  }
}
