import React, {Component} from 'react';
import {Table, Input, Icon, Button, Popconfirm} from 'ola-ui';
import {bind} from 'ola-toolkit';

class EditableCell extends Component {
  state = {
    value: this.props.value,
    editable: false,
  };

  @bind
  handleChange(e) {
    const value = e.target.value;
    this.setState({value});
  }

  @bind
  check() {
    this.setState({editable: false});
    if (this.props.onChange) {
      this.props.onChange(this.state.value);
    }
  }

  @bind
  edit() {
    this.setState({editable: true});
  }

  render() {
    const {value, editable} = this.state;
    return (
      <div style={{position: 'relative'}}>
        {
          editable ? (
            <Input
              value={value}
              onChange={this.handleChange}
              onPressEnter={this.check}
              suffix={
                <Icon
                  type="check"
                  style={{cursor: 'pointer'}}
                  onClick={this.check}
                />
              }
            />
          ) : (
            <div style={{paddingRight: 24}}>
              {value || ' '}
              <Icon
                type="edit"
                style={{
                  lineHeight: `14px`,
                  position: `absolute`,
                  right: 0,
                  top: `50%`,
                  marginTop: -7,
                  display: `inline-block`,
                }}
                onClick={this.edit}
              />
            </div>
          )
        }
      </div>
    );
  }
}

export default class Editable extends Component {

  constructor(props) {
    super(props);
    this.columns = [{
      title: 'name',
      dataIndex: 'name',
      width: '30%',
      render: (text, record) => (
        <EditableCell
          value={text}
          onChange={this.onCellChange(record.key, 'name')}
        />
      ),
    }, {
      title: 'age',
      dataIndex: 'age',
    }, {
      title: 'address',
      dataIndex: 'address',
    }, {
      title: 'operation',
      dataIndex: 'operation',
      render: (text, record) => {
        return (
          this.state.dataSource.length > 1 ?
            (
              <Popconfirm title="Sure to delete?" onConfirm={() => this.onDelete(record.key)}>
                <a href="javascript:;">Delete</a>
              </Popconfirm>
            ) : null
        );
      },
    }];

    this.state = {
      dataSource: [{
        key: '0',
        name: 'Edward King 0',
        age: '32',
        address: 'London, Park Lane no. 0',
      }, {
        key: '1',
        name: 'Edward King 1',
        age: '32',
        address: 'London, Park Lane no. 1',
      }],
      count: 2,
    };
  }

  @bind
  onCellChange(key, dataIndex) {
    return (value) => {
      const dataSource = [...this.state.dataSource];
      const target = dataSource.find(item => item.key === key);
      if (target) {
        target[dataIndex] = value;
        this.setState({dataSource});
      }
    };
  }

  @bind
  onDelete(key) {
    const dataSource = [...this.state.dataSource];
    this.setState({dataSource: dataSource.filter(item => item.key !== key)});
  }

  @bind
  handleAdd() {
    const {count, dataSource} = this.state;
    const newData = {
      key: count,
      name: `Edward King ${count}`,
      age: 32,
      address: `London, Park Lane no. ${count}`,
    };
    this.setState({
      dataSource: [...dataSource, newData],
      count: count + 1,
    });
  }

  render() {
    const {dataSource} = this.state;
    const columns = this.columns;
    return (
      <div>
        <Button onClick={this.handleAdd} type="primary" style={{marginBottom: 16}}>
          Add a row
        </Button>
        <Table bordered dataSource={dataSource} columns={columns}/>
      </div>
    );
  }

}
