import React, {Component} from 'react';
import {Tabs, Select} from 'ola-ui';
import {bind} from 'ola-toolkit';

const TabPane = Tabs.TabPane;

export default class Closable extends Component {

  constructor(props) {
    super(props);
    this.newTabIndex = 0;
    const panes = [
      {title: 'Tab 1', content: 'Content of Tab 1', key: '1'},
      {title: 'Tab 2', content: 'Content of Tab 2', key: '2'},
      {title: 'Tab 3', content: 'Content of Tab 3', key: '3', closable: false},
    ];
    this.state = {
      activeKey: panes[0].key,
      panes,
    };
  }

  @bind
  onChange(activeKey) {
    this.setState({activeKey});
  }

  @bind
  onEdit(targetKey, action) {
    this[action](targetKey);
  }

  @bind
  add() {
    const panes = this.state.panes;
    const activeKey = `newTab${this.newTabIndex++}`;
    panes.push({title: 'New Tab', content: 'Content of new Tab', key: activeKey});
    this.setState({panes, activeKey});
  }

  @bind
  remove(targetKey) {
    let activeKey = this.state.activeKey;
    let lastIndex;
    this.state.panes.forEach((pane, i) => {
      if (pane.key === targetKey) {
        lastIndex = i - 1;
      }
    });
    const panes = this.state.panes.filter(pane => pane.key !== targetKey);
    if (lastIndex >= 0 && activeKey === targetKey) {
      activeKey = panes[lastIndex].key;
    }
    this.setState({panes, activeKey});
  }

  render() {

    return (
      <div>
        <Tabs
          onChange={this.onChange}
          activeKey={this.state.activeKey}
          type="editable-card"
          onEdit={this.onEdit}
        >
          {this.state.panes.map(pane => <TabPane tab={pane.title} key={pane.key}
                                                 closable={pane.closable}>{pane.content}</TabPane>)}
        </Tabs>
      </div>
    );
  }

}
